#!/usr/bin/env python
from pathlib import Path
import json
from base64 import b64encode

original = json.loads(Path("compositions.json").read_text())
output = []

def nutrient(c, name):
    n = c["nutrients"]
    if name not in n or n[name].get("valeur") is None:
        return None
    return float(n[name]["valeur"]) * {
                "m": 1e-3,
                "µ": 1e-6,
            }.get(n[name]["unit"][0], 1) / 100 # it's per 100g in Ciqual's DB, we want per gram.

for c in original:
    try:
        output.append({
            "id": b64encode(bytes(c['name']['fr'], encoding="utf-8")).decode(),
            "name_fr": c["name"]["fr"],
            "name_en": c["name"]["en"],
            "carbohydrates": nutrient(c, "carbohydrate"),
            "proteins": nutrient(c, "protein"),
            "lipids": nutrient(c, "fat"),
            "energy": nutrient(c, "energy_with_fibers"),
            # "confidence":  TODO
        })
    except KeyError:
        print(f"skipping {c['name']['en']}: missing nutrient data")

Path("graphql_ready.ingredients.json").write_text(json.dumps(output, indent=2, ensure_ascii=False))

